#!/bin/sh
me=`basename $0`
usage(){
  cat <<EOF
$me - embed CIDFont/CMap/Font into PostScript file, revision 20011102
Usage:	$me [-F cidfontname] ... [-C cmapfile] ... [-f fontname] ... \\
	[-v] [psfile(s)]
Options:
	-v		verbose mode in PostScript
	-F cidfontname	specify CIDFont name	exists in gs /Resource/CIDFont
	-C cmapfile	specify CMap file name	exists in gs /Resource/CMap
	-f fontname	specify Font name	exists in gs /Resource/Font
	-h		print this message
Copyright:	(C) 2001 Taiji Yamada <taiji@aihara.co.jp> and gs-cjk project
License:	This program is provided under BSD license.
Acknowledgment:	It is a pleasure to thank "John" <qiang_lu@21cn.com> and
		suzuki toshiya <mpsuzuki@hiroshima-u.ac.jp>.
EOF
}
FontDir=`echo "pssystemparams /FontResourceDir get =" | gsnd -q - `
#FontDir=/usr/local/share/ghostscript/Resource/Font
ResourceDir=`echo "pssystemparams /GenericResourceDir get =" | gsnd -q - `
#ResourceDir=/usr/local/share/ghostscript/Resource
CMapDir=${ResourceDir}/CMap
CIDFontDir=${ResourceDir}/CIDFont

sedscript="${TMPDIR:=/tmp}/${USER}-$me-$$"

echo '' > $sedscript
while getopts C:F:f:hv c; do
  case $c in
  v)	################################################################
    cat <<EOF >> $sedscript
/^%%BeginProlog/{
a\\
\\
/orighandleerror errordict /handleerror get def\\
errordict begin\\
  /handleerror {\\
    errordict begin\\
      $error begin\\
        initgraphics\\
        /Courier findfont 10 scalefont setfont\\
        50 700 moveto\\
        errorname 256 string cvs show 50 currentpoint exch pop 10 sub moveto\\
        currentdict /ostack known {\\
          ostack {\\
            256 string cvs show 50 currentpoint exch pop 10 sub moveto\\
          } forall\\
        } if\\
        showpage\\
      end\\
    end\\
%    orighandleerror\\
  } bind def\\
end
}
EOF
    ;;
  C)	################################################################
    if [ -f $CMapDir/$OPTARG ]; then
      cat <<EOF >> $sedscript
/^%%BeginProlog/{
a\\

r $CMapDir/$OPTARG
}
EOF
    else
      echo "Error: CMap $OPTARG not found." 1>&2
    fi
    ;;
  F)	################################################################
    if [ -f $CIDFontDir/$OPTARG ]; then
      cat <<EOF >> $sedscript
/^%%BeginProlog/{
a\\

r $CIDFontDir/$OPTARG
}
EOF
    else
      echo "Error: CIDFont $OPTARG not found." 1>&2
    fi
    ;;
  f)	################################################################
    if [ -f $FontDir/$OPTARG ]; then
      cat <<EOF >> $sedscript
/^%%BeginProlog/{
a\\

r $FontDir/$OPTARG
}
EOF
    else
      echo "Error: Font $OPTARG not found." 1>&2
    fi
    ;;
  h)	################################################################
    rm -f $sedscript; usage; exit 0
    ;;
  esac
done
shift `expr $OPTIND - 1`

(sed -f $sedscript $@ | sed -e '/^%%EOF/d' ; echo "%%EOF")
#sed -f $sedscript $@

rm -f $sedscript
